pub struct EncryptionConfig {
pub enabled: bool,
pub passphrase: Option<String>,
pub env_var: Option<String>,
}Expand description
Encryption configuration
Fields
enabled: boolWhether encryption is enabled
passphrase: Option<String>Passphrase for encryption/decryption (if enabled)
env_var: Option<String>Environment variable name to read passphrase from
Implementations
Sourceimpl EncryptionConfig
impl EncryptionConfig
Sourcepub fn new(passphrase: String) -> Self
pub fn new(passphrase: String) -> Self
Create a new encryption config with the given passphrase
Sourcepub fn from_env(env_var: String) -> Self
pub fn from_env(env_var: String) -> Self
Create a new encryption config that reads passphrase from environment variable
Sourcepub fn get_passphrase(&self) -> Result<Option<String>>
pub fn get_passphrase(&self) -> Result<Option<String>>
Get the passphrase, either directly or from environment