pub struct StateEncryption { /* private fields */ }Expand description
Transparent encryption wrapper for file operations.
This provides a simple interface for encrypting/decrypting files transparently without changing the rest of the codebase.
Implementations
Sourceimpl StateEncryption
impl StateEncryption
Sourcepub fn new(config: EncryptionConfig) -> Result<Self>
pub fn new(config: EncryptionConfig) -> Result<Self>
Create a new state encryption handler
Sourcepub fn is_enabled(&self) -> bool
pub fn is_enabled(&self) -> bool
Check if encryption is enabled and we have a passphrase